==> haskell-fdo-notify-0.3.1-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-GFM9EfOOjNk7Gsos4mpDPH
key: fdo-notify-0.3.1-GFM9EfOOjNk7Gsos4mpDPH
license: BSD-3-Clause
maintainer: max.rabkin@gmail.com
author: Max Rabkin
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
abi: 89467a419b9893926e8dd8aa1937aea8
exposed: True
exposed-modules:
    DBus.Notify
import-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-GFM9EfOOjNk7Gsos4mpDPH
depends:
    base-4.11.1.0 containers-0.5.11.0 dbus-1.0.1-AvxAfmcvTkvHf9V7AJ6Mbc
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             dbus-1.0.1-AvxAfmcvTkvHf9V7AJ6Mbc=d58dbb06ad220aec2c762bc12eb4cfe9
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-BdCv4e948zWFetrDV4ulmt
key: fdo-notify-0.3.1-BdCv4e948zWFetrDV4ulmt
license: BSD-3-Clause
maintainer: max.rabkin@gmail.com
author: Max Rabkin
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
abi: 64f6876f792b4738881fca0586a79e77
exposed: True
exposed-modules:
    DBus.Notify
import-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-BdCv4e948zWFetrDV4ulmt
depends:
    base-4.11.1.0 containers-0.5.11.0 dbus-1.0.1-3g4nQbIDpHJHhShBr82J8A
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             dbus-1.0.1-3g4nQbIDpHJHhShBr82J8A=65741e6a6a2777d2940fd3271408b147
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
